package Perinci::Examples::Bin::Any;

our $DATE = '2021-01-30'; # DATE
our $VERSION = '0.071'; # VERSION

use 5.010001;

1;
# ABSTRACT: Perinci example scripts (using Perinci::CmdLine::Any)

__END__

=pod

=encoding UTF-8

=head1 NAME

Perinci::Examples::Bin::Any - Perinci example scripts (using Perinci::CmdLine::Any)

=head1 VERSION

This document describes version 0.071 of Perinci::Examples::Bin::Any (from Perl distribution Perinci-Examples-Bin-Any), released on 2021-01-30.

=head1 DESCRIPTION

This distribution contains example scripts in C<bin/> which use
L<Perinci::CmdLine::Any>.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Examples-Bin-Any>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Perinci-Examples-Bin-Any>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Examples-Bin-Any>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Perinci::Examples::Bin::Classic>

L<Perinci::Examples::Bin::Lite>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021, 2020, 2015, 2014 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
